@@ -2,6 +2,8 @@
 
 
 class DbColumn:
+    separator = '.'
+
     att = 'att'
     classification = 'classification'
     confidence = 'confidence'
@@ -14,6 +16,8 @@ class DbColumn:
     flow = 'flow'
     fluidity = 'fluidity'
     fromtraveltime = 'from_travel_time'
+    fromroad = 'from_road'
+    fromturnratio = 'from_turn_ratio'
     fromzonepoint = 'from_zone_point'
     geom = 'geom'
     id = 'id'
@@ -22,14 +26,21 @@ class DbColumn:
     networkdataquality = 'network_data_quality'
     networkindicator = 'network_indicator'
     occupancy = 'occupancy'
+    ratio = 'ratio'
     road = 'road'
+    roadcenter = 'road_center'
+    samples = 'samples'
     sampletime = 'sample_time'
+    timestamp = 'timestamp'
     speed = 'speed'
     totraveltime = 'to_travel_time'
+    toroad = 'to_road'
+    toturnratio = 'to_turn_ratio'
     tozonepoint = 'to_zone_point'
     traveltime = 'travel_time'
     validfrom = 'valid_from'
     validto = 'valid_to'
+    vehicle = 'vehicle'
     webatt = 'web_att'
 
 
@@ -42,9 +53,11 @@ class DbTable:
     networkdataquality = 'network_data_quality'
     networkindicator = 'network_indicator'
     road = 'road'
+    roadcenter = 'road_center'
     roaddatapoint = 'road_data_point'
     roaddataquality = 'road_data_quality'
     roadindicator = 'road_indicator'
+    turnratio = 'turn_ratio'
     zonepoint = 'zone_point'
     zonepointtraveltime = 'zone_point_travel_time'
 
@@ -59,16 +72,25 @@ class Message:
 class MessageData(DbColumn):
     csvseparator = ';'
     encoding = 'utf-8'
+    separator = '_'
 
     status = 'status'
 
     late = -2
     nan = -1
 
+    hendday = 21
+    hstartday = 6
+
+    max = 'max'
+    mean = 'mean'
+    min = 'min'
+
 
 class AttId(DbColumn):
     centerxy = 'centerxy'
     datapointseids = 'datapoints'
+    datatypeeid = 'datatypeeid'
     ffspeed = 'ffspeed'
     fow = 'fow'
     frc = 'frc'
@@ -103,35 +125,43 @@ class MessageKind:
     datapoint = 'datapoint'
     datatype = 'datatype'
     indicator = 'indicator'
+    mappingroadsdatapoints = 'mappingroadsdatapoints'
     network = 'network'
+    partitions = 'partitions'
+    partitionstraveltime = 'partitionstraveltime'
     traveltime = 'traveltime'
+    turnratio = 'turnratio'
+    vehicles = 'vehicles'
 
     karrusrd = 'karrusrd'
     metropme = 'metropme'
     road = 'road'
+    roadcenter = 'roadcenter'
     tomtomfcd = 'tomtomfcd'
     zonepoint = 'zonepoint'
 
 
-class RequestParam:
+class RequestParam(MessageKind):
     separator = ','
 
     internalflag = 'internal'
 
-    datapoint = 'datapoint'
-    datatype = 'datatype'
     eid = 'eid'
+    fields = 'fields'
     fromdatetime = 'fromdatetime'
     frompoint = 'frompoint'
-    indicator = 'indicator'
+    fromroad = 'fromroad'
     period = 'period'
-    topoint = 'topoint'
+    sampling = 'sampling'
     todatetime = 'todatetime'
+    topoint = 'topoint'
+    toroad = 'toroad'
+    window = 'window'
     within = 'within'
 
     day = 'day'
-    week = 'week'
     month = 'month'
+    week = 'week'
 
 
 class RequestPath(MessageKind):
